Learn R Programming

wtest (version 3.0)

methylation.recode: Recode methylation data

Description

This function performs redocing for methylation data by a K-means clustering method. The methylation data set will be recoded into two (high and low) levels according to the methylated level of each CpG site.

Usage

methylation.recode(data)

Arguments

data

a data frame or matrix contains methylation data in the columns.

Examples

Run this code
# NOT RUN {
data(methylation)
data.recoded <- methylation.recode(methylation)
# }

Run the code above in your browser using DataLab