This function performs redocing for methylation data by a K-means clustering method. The methylation data set will be recoded into two (high and low) levels according to the methylated level of each CpG site.
Usage
methylation.recode(data)
Arguments
data
a data frame or matrix contains methylation data in the columns.